"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createPool = void 0;
const bindPool_1 = require("../binders/bindPool");
const Logger_1 = require("../Logger");
const createClientConfiguration_1 = require("./createClientConfiguration");
const createConnectionPool_1 = require("./createConnectionPool");
const createPgDriverFactory_1 = require("./createPgDriverFactory");
const createPoolConfiguration_1 = require("./createPoolConfiguration");
/**
 * @param connectionUri PostgreSQL [Connection URI](https://www.postgresql.org/docs/current/libpq-connect.html#LIBPQ-CONNSTRING).
 */
const createPool = async (connectionUri, clientConfigurationInput) => {
    const clientConfiguration = (0, createClientConfiguration_1.createClientConfiguration)(connectionUri, clientConfigurationInput);
    const createDriver = clientConfiguration.driverFactory ?? (0, createPgDriverFactory_1.createPgDriverFactory)();
    const driver = await createDriver({
        // TODO resolve name conflict
        driverConfiguration: clientConfiguration,
    });
    const pool = (0, createConnectionPool_1.createConnectionPool)({
        driver,
        ...(0, createPoolConfiguration_1.createPoolConfiguration)(clientConfiguration),
    });
    return (0, bindPool_1.bindPool)(Logger_1.Logger.child({
        poolId: pool.id(),
    }), pool, clientConfiguration);
};
exports.createPool = createPool;
//# sourceMappingURL=createPool.js.map