/// <reference types="node" />
import { type ArraySqlToken, type BinarySqlToken, type DateSqlToken, type FragmentSqlToken, type IdentifierSqlToken, type IntervalInput, type IntervalSqlToken, type JsonBinarySqlToken, type JsonSqlToken, type ListSqlToken, type PrimitiveValueExpression, type SerializableValue, type SqlFragment, type SqlToken as SqlTokenType, type TimestampSqlToken, type TypeNameIdentifier, type UnnestSqlToken, type ValueExpression } from '../types';
import { z } from 'zod';
export declare const createSqlTag: <K extends PropertyKey, P extends z.ZodTypeAny, Z extends Record<K, P>>(configuration?: {
    typeAliases?: Z;
}) => {
    array: (values: readonly PrimitiveValueExpression[], memberType: SqlTokenType | TypeNameIdentifier) => ArraySqlToken;
    binary: (data: Buffer) => BinarySqlToken;
    date: (date: Date) => DateSqlToken;
    fragment: (parts: readonly string[], ...args: readonly ValueExpression[]) => FragmentSqlToken;
    identifier: (names: readonly string[]) => IdentifierSqlToken;
    interval: (interval: IntervalInput) => IntervalSqlToken;
    join: (members: readonly ValueExpression[], glue: SqlFragment) => ListSqlToken;
    json: (value: SerializableValue) => JsonSqlToken;
    jsonb: (value: SerializableValue) => JsonBinarySqlToken;
    literalValue: (value: string) => SqlFragment;
    timestamp: (date: Date) => TimestampSqlToken;
    type: <T extends z.ZodTypeAny>(parser: T) => (parts: readonly string[], ...args: readonly ValueExpression[]) => Readonly<{
        parser: T;
        type: "SLONIK_TOKEN_QUERY";
        sql: string;
        values: PrimitiveValueExpression[];
    }>;
    typeAlias: <Y extends keyof Z>(parserAlias: Y) => (parts: readonly string[], ...args: readonly ValueExpression[]) => Readonly<{
        parser: Z[Y];
        type: "SLONIK_TOKEN_QUERY";
        sql: string;
        values: PrimitiveValueExpression[];
    }>;
    unnest: (tuples: ReadonlyArray<readonly PrimitiveValueExpression[]>, columnTypes: Array<[...string[], TypeNameIdentifier]> | Array<SqlFragment | TypeNameIdentifier>) => UnnestSqlToken;
    unsafe: (parts: readonly string[], ...args: readonly ValueExpression[]) => Readonly<{
        parser: z.ZodAny;
        type: "SLONIK_TOKEN_QUERY";
        sql: string;
        values: PrimitiveValueExpression[];
    }>;
};
//# sourceMappingURL=createSqlTag.d.ts.map