"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createSqlTokenSqlFragment = void 0;
const errors_1 = require("../errors");
const createArraySqlFragment_1 = require("../sqlFragmentFactories/createArraySqlFragment");
const createBinarySqlFragment_1 = require("../sqlFragmentFactories/createBinarySqlFragment");
const createDateSqlFragment_1 = require("../sqlFragmentFactories/createDateSqlFragment");
const createFragmentSqlFragment_1 = require("../sqlFragmentFactories/createFragmentSqlFragment");
const createIdentifierSqlFragment_1 = require("../sqlFragmentFactories/createIdentifierSqlFragment");
const createIntervalSqlFragment_1 = require("../sqlFragmentFactories/createIntervalSqlFragment");
const createJsonSqlFragment_1 = require("../sqlFragmentFactories/createJsonSqlFragment");
const createListSqlFragment_1 = require("../sqlFragmentFactories/createListSqlFragment");
const createQuerySqlFragment_1 = require("../sqlFragmentFactories/createQuerySqlFragment");
const createTimestampSqlFragment_1 = require("../sqlFragmentFactories/createTimestampSqlFragment");
const createUnnestSqlFragment_1 = require("../sqlFragmentFactories/createUnnestSqlFragment");
const tokens_1 = require("../tokens");
const createSqlTokenSqlFragment = (token, greatestParameterPosition) => {
    if (token.type === tokens_1.ArrayToken) {
        return (0, createArraySqlFragment_1.createArraySqlFragment)(token, greatestParameterPosition);
    }
    else if (token.type === tokens_1.BinaryToken) {
        return (0, createBinarySqlFragment_1.createBinarySqlFragment)(token, greatestParameterPosition);
    }
    else if (token.type === tokens_1.DateToken) {
        return (0, createDateSqlFragment_1.createDateSqlFragment)(token, greatestParameterPosition);
    }
    else if (token.type === tokens_1.FragmentToken) {
        return (0, createFragmentSqlFragment_1.createFragmentSqlFragment)(token, greatestParameterPosition);
    }
    else if (token.type === tokens_1.IdentifierToken) {
        return (0, createIdentifierSqlFragment_1.createIdentifierSqlFragment)(token);
    }
    else if (token.type === tokens_1.IntervalToken) {
        return (0, createIntervalSqlFragment_1.createIntervalSqlFragment)(token, greatestParameterPosition);
    }
    else if (token.type === tokens_1.JsonBinaryToken) {
        return (0, createJsonSqlFragment_1.createJsonSqlFragment)(token, greatestParameterPosition, true);
    }
    else if (token.type === tokens_1.JsonToken) {
        return (0, createJsonSqlFragment_1.createJsonSqlFragment)(token, greatestParameterPosition, false);
    }
    else if (token.type === tokens_1.ListToken) {
        return (0, createListSqlFragment_1.createListSqlFragment)(token, greatestParameterPosition);
    }
    else if (token.type === tokens_1.QueryToken) {
        return (0, createQuerySqlFragment_1.createQuerySqlFragment)(token, greatestParameterPosition);
    }
    else if (token.type === tokens_1.TimestampToken) {
        return (0, createTimestampSqlFragment_1.createTimestampSqlFragment)(token, greatestParameterPosition);
    }
    else if (token.type === tokens_1.UnnestToken) {
        return (0, createUnnestSqlFragment_1.createUnnestSqlFragment)(token, greatestParameterPosition);
    }
    throw new errors_1.UnexpectedStateError('Unexpected token type.');
};
exports.createSqlTokenSqlFragment = createSqlTokenSqlFragment;
//# sourceMappingURL=createSqlTokenSqlFragment.js.map