"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createArraySqlFragment = void 0;
const errors_1 = require("../errors");
const createSqlTokenSqlFragment_1 = require("../factories/createSqlTokenSqlFragment");
const escapeIdentifier_1 = require("../utilities/escapeIdentifier");
const formatSlonikPlaceholder_1 = require("../utilities/formatSlonikPlaceholder");
const isPrimitiveValueExpression_1 = require("../utilities/isPrimitiveValueExpression");
const isSqlToken_1 = require("../utilities/isSqlToken");
const createArraySqlFragment = (token, greatestParameterPosition) => {
    let placeholderIndex = greatestParameterPosition;
    for (const value of token.values) {
        if (token.memberType === 'bytea') {
            if (Buffer.isBuffer(value)) {
                continue;
            }
            else {
                throw new errors_1.InvalidInputError('Invalid array member type. Non-buffer value bound to bytea type.');
            }
        }
        if (!(0, isPrimitiveValueExpression_1.isPrimitiveValueExpression)(value)) {
            throw new errors_1.InvalidInputError('Invalid array member type. Must be a primitive value expression.');
        }
    }
    const values = [token.values];
    placeholderIndex++;
    let sql = (0, formatSlonikPlaceholder_1.formatSlonikPlaceholder)(placeholderIndex) + '::';
    if ((0, isSqlToken_1.isSqlToken)(token.memberType) &&
        token.memberType.type === 'SLONIK_TOKEN_FRAGMENT') {
        const sqlFragment = (0, createSqlTokenSqlFragment_1.createSqlTokenSqlFragment)(token.memberType, placeholderIndex);
        if (sqlFragment.values.length > 0) {
            throw new errors_1.UnexpectedStateError('Type is not expected to have a value binding.');
        }
        sql += sqlFragment.sql;
    }
    else if (typeof token.memberType === 'string') {
        sql += (0, escapeIdentifier_1.escapeIdentifier)(token.memberType) + '[]';
    }
    else {
        throw new errors_1.InvalidInputError('Unsupported `memberType`. `memberType` must be a string or SqlToken of "SLONIK_TOKEN_FRAGMENT" type.');
    }
    return {
        sql,
        values,
    };
};
exports.createArraySqlFragment = createArraySqlFragment;
//# sourceMappingURL=createArraySqlFragment.js.map