"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createListSqlFragment = void 0;
const errors_1 = require("../errors");
const createPrimitiveValueExpressions_1 = require("../factories/createPrimitiveValueExpressions");
const createSqlTokenSqlFragment_1 = require("../factories/createSqlTokenSqlFragment");
const formatSlonikPlaceholder_1 = require("../utilities/formatSlonikPlaceholder");
const isPrimitiveValueExpression_1 = require("../utilities/isPrimitiveValueExpression");
const isSqlToken_1 = require("../utilities/isSqlToken");
const createListSqlFragment = (token, greatestParameterPosition) => {
    const values = [];
    const placeholders = [];
    let placeholderIndex = greatestParameterPosition;
    if (token.members.length === 0) {
        throw new errors_1.InvalidInputError('Value list must have at least 1 member.');
    }
    for (const member of token.members) {
        if ((0, isSqlToken_1.isSqlToken)(member)) {
            const sqlFragment = (0, createSqlTokenSqlFragment_1.createSqlTokenSqlFragment)(member, placeholderIndex);
            placeholders.push(sqlFragment.sql);
            placeholderIndex += sqlFragment.values.length;
            values.push(...sqlFragment.values);
        }
        else if ((0, isPrimitiveValueExpression_1.isPrimitiveValueExpression)(member)) {
            placeholders.push((0, formatSlonikPlaceholder_1.formatSlonikPlaceholder)(++placeholderIndex));
            values.push(member);
        }
        else {
            throw new errors_1.InvalidInputError('Invalid list member type. Must be a SQL token or a primitive value expression.');
        }
    }
    return {
        sql: placeholders.join(token.glue.sql),
        values: (0, createPrimitiveValueExpressions_1.createPrimitiveValueExpressions)(values),
    };
};
exports.createListSqlFragment = createListSqlFragment;
//# sourceMappingURL=createListSqlFragment.js.map